@@ -41,7 +41,7 @@ class KWaveSaverInterface : public KScreenSaverInterface
 
 public:
     virtual KAboutData* aboutData() {
-        return new KAboutData( "kwave.kss", 0, ki18n( "Bitmap Wave Screen Saver" ), "2.2.0", ki18n( "Bitmap Wave Screen Saver" ) );
+        return new KAboutData( "kwave.kss", "klock", ki18n( "Bitmap Wave Screen Saver" ), "2.2.0", ki18n( "Bitmap Wave Screen Saver" ) );
     }
 
 
@@ -77,6 +77,7 @@ KWaveSetup::KWaveSetup( QWidget *parent)
         QPalette palette;
         palette.setColor( preview->backgroundRole(), Qt::black );
         preview->setPalette( palette );
+	preview->setAutoFillBackground(true);
 
 	preview->show();    // otherwise saver does not get correct size
 	saver = new KWaveSaver( preview->winId() );
@@ -135,6 +136,7 @@ KWaveSaver::KWaveSaver( WId id ) : KScreenSaver( id )
             QPalette palette;
             palette.setColor( backgroundRole(), Qt::black );
             setPalette( palette );
+	    setAutoFillBackground(true);
         }
 	wave = new Wave();
 	embed(wave);
